@@ -1,5 +1,9 @@
 svc <- paws::timestreamquery()
 
+test_that("describe_account_settings", {
+  expect_error(svc$describe_account_settings(), NA)
+})
+
 test_that("describe_endpoints", {
   expect_error(svc$describe_endpoints(), NA)
 })
